summaryrefslogtreecommitdiff
path: root/previewer
diff options
context:
space:
mode:
authorPerberos <[email protected]>2011-11-09 18:44:56 -0300
committerPerberos <[email protected]>2011-11-09 18:44:56 -0300
commitda7bb154d27d3b872867223a5df60df8f5fb6e7d (patch)
treec1a40fbb481956cf2fda2263bf78389622eba0a5 /previewer
parent342e9e9bf91625bf6f0102fb7bbc652dea222064 (diff)
downloadatril-da7bb154d27d3b872867223a5df60df8f5fb6e7d.tar.bz2
atril-da7bb154d27d3b872867223a5df60df8f5fb6e7d.tar.xz
renaming evince to atril
Diffstat (limited to 'previewer')
-rw-r--r--previewer/Makefile.am16
-rw-r--r--previewer/ev-previewer-window.c16
-rw-r--r--previewer/ev-previewer-window.h10
-rw-r--r--previewer/ev-previewer.c12
4 files changed, 27 insertions, 27 deletions
diff --git a/previewer/Makefile.am b/previewer/Makefile.am
index ab8f95d7..2ef31186 100644
--- a/previewer/Makefile.am
+++ b/previewer/Makefile.am
@@ -1,13 +1,13 @@
-bin_PROGRAMS = evince-previewer
+bin_PROGRAMS = atril-previewer
-evince_previewer_SOURCES = \
+atril_previewer_SOURCES = \
ev-previewer.c \
ev-previewer-window.h \
ev-previewer-window.c
-evince_previewer_CPPFLAGS = \
- -DEVINCEDATADIR=\"$(pkgdatadir)\" \
+atril_previewer_CPPFLAGS = \
+ -DATRILDATADIR=\"$(pkgdatadir)\" \
-I$(top_srcdir) \
-I$(top_builddir) \
-I$(top_srcdir)/libdocument \
@@ -15,19 +15,19 @@ evince_previewer_CPPFLAGS = \
-I$(top_srcdir)/libmisc \
$(AM_CPPFLAGS)
-evince_previewer_CFLAGS = \
+atril_previewer_CFLAGS = \
$(PREVIEWER_CFLAGS) \
$(WARN_CFLAGS) \
$(DISABLE_DEPRECATED) \
$(AM_CFLAGS)
-evince_previewer_LDFLAGS = $(AM_LDFLAGS)
+atril_previewer_LDFLAGS = $(AM_LDFLAGS)
if PLATFORM_WIN32
-evince_previewer_LDFLAGS += -mwindows
+atril_previewer_LDFLAGS += -mwindows
endif
-evince_previewer_LDADD = \
+atril_previewer_LDADD = \
$(top_builddir)/libdocument/libevdocument.la \
$(top_builddir)/libview/libevview.la \
$(top_builddir)/libmisc/libevmisc.la \
diff --git a/previewer/ev-previewer-window.h b/previewer/ev-previewer-window.h
index 483d0245..7d1e686b 100644
--- a/previewer/ev-previewer-window.h
+++ b/previewer/ev-previewer-window.h
@@ -1,14 +1,14 @@
/* ev-previewer-window.h:
- * this file is part of evince, a mate document viewer
+ * this file is part of atril, a mate document viewer
*
* Copyright (C) 2009 Carlos Garcia Campos <[email protected]>
*
- * Evince is free software; you can redistribute it and/or modify it
+ * Atril is free software; you can redistribute it and/or modify it
* under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
- * Evince is distributed in the hope that it will be useful, but
+ * Atril is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* General Public License for more details.
@@ -23,8 +23,8 @@
#include <gtk/gtk.h>
-#include <evince-document.h>
-#include <evince-view.h>
+#include <atril-document.h>
+#include <atril-view.h>
G_BEGIN_DECLS
diff --git a/previewer/ev-previewer-window.c b/previewer/ev-previewer-window.c
index bfef10dc..444d8e79 100644
--- a/previewer/ev-previewer-window.c
+++ b/previewer/ev-previewer-window.c
@@ -1,14 +1,14 @@
/* ev-previewer-window.c:
* this file is part of evince, a mate document viewer
*
* Copyright (C) 2009 Carlos Garcia Campos <[email protected]>
*
* Evince is free software; you can redistribute it and/or modify it
* under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* Evince is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* General Public License for more details.
@@ -24,7 +24,7 @@
#include <gtk/gtkunixprint.h>
#endif
#include <glib/gi18n.h>
-#include <evince-view.h>
+#include <atril-view.h>
#include "ev-page-action.h"
#include "ev-previewer-window.h"
@@ -484,10 +484,10 @@ data_dir (void)
gchar *dir;
dir = g_win32_get_package_installation_directory_of_module (NULL);
- datadir = g_build_filename (dir, "share", "evince", NULL);
+ datadir = g_build_filename (dir, "share", "atril", NULL);
g_free (dir);
#else
- datadir = g_strdup (EVINCEDATADIR);
+ datadir = g_strdup (ATRILDATADIR);
#endif
return datadir;
@@ -581,9 +581,9 @@ ev_previewer_window_constructor (GType type,
gtk_window_add_accel_group (GTK_WINDOW (window),
gtk_ui_manager_get_accel_group (window->ui_manager));
datadir = data_dir ();
- ui_path = g_build_filename (datadir, "evince-previewer-ui.xml", NULL);
+ ui_path = g_build_filename (datadir, "atril-previewer-ui.xml", NULL);
if (!gtk_ui_manager_add_ui_from_file (window->ui_manager, ui_path, &error)) {
- g_warning ("Failed to load ui from evince-previewer-ui.xml: %s", error->message);
+ g_warning ("Failed to load ui from atril-previewer-ui.xml: %s", error->message);
g_error_free (error);
}
g_free (ui_path);
@@ -1,14 +1,14 @@
/* ev-previewer-window.c:
- * this file is part of evince, a mate document viewer
+ * this file is part of atril, a mate document viewer
*
* Copyright (C) 2009 Carlos Garcia Campos <[email protected]>
@@ -1,14 +1,14 @@
* Copyright (C) 2009 Carlos Garcia Campos <[email protected]>
*
- * Evince is free software; you can redistribute it and/or modify it
+ * Atril is free software; you can redistribute it and/or modify it
* under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
@@ -1,14 +1,14 @@
* (at your option) any later version.
*
- * Evince is distributed in the hope that it will be useful, but
+ * Atril is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
diff --git a/previewer/ev-previewer.c b/previewer/ev-previewer.c
index a836cf39..7a23b3e4 100644
--- a/previewer/ev-previewer.c
+++ b/previewer/ev-previewer.c
@@ -1,14 +1,14 @@
/* ev-previewer.c:
* this file is part of evince, a mate document viewer
*
* Copyright (C) 2009 Carlos Garcia Campos <[email protected]>
*
* Evince is free software; you can redistribute it and/or modify it
* under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* Evince is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* General Public License for more details.
@@ -22,8 +22,8 @@
#include <gtk/gtk.h>
#include <glib/gi18n.h>
-#include <evince-document.h>
-#include <evince-view.h>
+#include <atril-document.h>
+#include <atril-view.h>
#include "ev-previewer-window.h"
@@ -176,7 +176,7 @@ main (gint argc, gchar **argv)
ev_stock_icons_init ();
g_set_application_name (_("MATE Document Previewer"));
- gtk_window_set_default_icon_name ("evince");
+ gtk_window_set_default_icon_name ("atril");
model = ev_document_model_new ();
window = ev_previewer_window_new (model);
@@ -1,14 +1,14 @@
/* ev-previewer.c:
- * this file is part of evince, a mate document viewer
+ * this file is part of atril, a mate document viewer
*
* Copyright (C) 2009 Carlos Garcia Campos <[email protected]>
@@ -1,14 +1,14 @@
* Copyright (C) 2009 Carlos Garcia Campos <[email protected]>
*
- * Evince is free software; you can redistribute it and/or modify it
+ * Atril is free software; you can redistribute it and/or modify it
* under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
@@ -1,14 +1,14 @@
* (at your option) any later version.
*
- * Evince is distributed in the hope that it will be useful, but
+ * Atril is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU